==> scale-nucleus-0.1.11.tar.gz: scale-nucleus-0.1.11/nucleus/constants.py <==
ANNOTATIONS_IGNORED_KEY = "annotations_ignored"
ANNOTATIONS_KEY = "annotations"
ANNOTATIONS_PROCESSED_KEY = "annotations_processed"
ANNOTATION_ID_KEY = "annotation_id"
ANNOTATION_METADATA_SCHEMA_KEY = "annotation_metadata_schema"
BOX_TYPE = "box"
POLYGON_TYPE = "polygon"
MASK_TYPE = "mask"
SEGMENTATION_TYPE = "segmentation"
CUBOID_TYPE = "cuboid"
ANNOTATION_TYPES = (BOX_TYPE, POLYGON_TYPE, SEGMENTATION_TYPE, CUBOID_TYPE)
ANNOTATION_UPDATE_KEY = "update"
AUTOTAGS_KEY = "autotags"
EXPORTED_ROWS = "exportedRows"
CLASS_PDF_KEY = "class_pdf"
CONFIDENCE_KEY = "confidence"
DATASET_ID_KEY = "dataset_id"
DATASET_ITEM_IDS_KEY = "dataset_item_ids"
DATASET_ITEM_ID_KEY = "dataset_item_id"
DATASET_LENGTH_KEY = "length"
DATASET_MODEL_RUNS_KEY = "model_run_ids"
DATASET_NAME_KEY = "name"
DATASET_SLICES_KEY = "slice_ids"
DEFAULT_ANNOTATION_UPDATE_MODE = False
DEFAULT_NETWORK_TIMEOUT_SEC = 120
DIMENSIONS_KEY = "dimensions"
EMBEDDINGS_URL_KEY = "embeddings_url"
ERRORS_KEY = "errors"
ERROR_CODES = "error_codes"
ERROR_ITEMS = "upload_errors"
ERROR_PAYLOAD = "error_payload"
GEOMETRY_KEY = "geometry"
HEIGHT_KEY = "height"
IGNORED_ITEMS = "ignored_items"
IMAGE_KEY = "image"
IMAGE_URL_KEY = "image_url"
INDEX_KEY = "index"
ITEMS_KEY = "items"
ITEM_ID_KEY = "item_id"
ITEM_KEY = "item"
ITEM_METADATA_SCHEMA_KEY = "item_metadata_schema"
JOB_ID_KEY = "job_id"
LABEL_KEY = "label"
MASK_URL_KEY = "mask_url"
MESSAGE_KEY = "message"
METADATA_KEY = "metadata"
MODEL_ID_KEY = "model_id"
MODEL_RUN_ID_KEY = "model_run_id"
NAME_KEY = "name"
NEW_ITEMS = "new_items"
NUCLEUS_ENDPOINT = "https://api.scale.com/v1/nucleus"
ORIGINAL_IMAGE_URL_KEY = "original_image_url"
POSITION_KEY = "position"
PREDICTIONS_IGNORED_KEY = "predictions_ignored"
PREDICTIONS_PROCESSED_KEY = "predictions_processed"
REFERENCE_IDS_KEY = "reference_ids"
REFERENCE_ID_KEY = "reference_id"
REQUEST_ID_KEY = "requestId"
SEGMENTATIONS_KEY = "segmentations"
SLICE_ID_KEY = "slice_id"
STATUS_CODE_KEY = "status_code"
STATUS_KEY = "status"
SUCCESS_STATUS_CODES = [200, 201, 202]
TYPE_KEY = "type"
UPDATED_ITEMS = "updated_items"
UPDATE_KEY = "update"
VERTICES_KEY = "vertices"
WIDTH_KEY = "width"
YAW_KEY = "yaw"
X_KEY = "x"
Y_KEY = "y"
Z_KEY = "z"

==> scale-nucleus-0.1.15.tar.gz: scale-nucleus-0.1.15/nucleus/constants.py <==
ANNOTATIONS_IGNORED_KEY = "annotations_ignored"
ANNOTATIONS_KEY = "annotations"
ANNOTATIONS_PROCESSED_KEY = "annotations_processed"
ANNOTATION_ID_KEY = "annotation_id"
ANNOTATION_METADATA_SCHEMA_KEY = "annotation_metadata_schema"
BOX_TYPE = "box"
POLYGON_TYPE = "polygon"
MASK_TYPE = "mask"
SEGMENTATION_TYPE = "segmentation"
CUBOID_TYPE = "cuboid"
ANNOTATION_TYPES = (BOX_TYPE, POLYGON_TYPE, SEGMENTATION_TYPE, CUBOID_TYPE)
ANNOTATION_UPDATE_KEY = "update"
AUTOTAGS_KEY = "autotags"
EXPORTED_ROWS = "exportedRows"
CLASS_PDF_KEY = "class_pdf"
CONFIDENCE_KEY = "confidence"
DATASET_ID_KEY = "dataset_id"
DATASET_ITEM_IDS_KEY = "dataset_item_ids"
DATASET_ITEM_ID_KEY = "dataset_item_id"
DATASET_LENGTH_KEY = "length"
DATASET_MODEL_RUNS_KEY = "model_run_ids"
DATASET_NAME_KEY = "name"
DATASET_SLICES_KEY = "slice_ids"
DEFAULT_ANNOTATION_UPDATE_MODE = False
DEFAULT_NETWORK_TIMEOUT_SEC = 120
DIMENSIONS_KEY = "dimensions"
EMBEDDINGS_URL_KEY = "embeddings_urls"
EMBEDDING_DIMENSION_KEY = "embedding_dimension"
ERRORS_KEY = "errors"
ERROR_CODES = "error_codes"
ERROR_ITEMS = "upload_errors"
ERROR_PAYLOAD = "error_payload"
GEOMETRY_KEY = "geometry"
HEIGHT_KEY = "height"
IGNORED_ITEMS = "ignored_items"
IMAGE_KEY = "image"
IMAGE_URL_KEY = "image_url"
INDEX_KEY = "index"
ITEMS_KEY = "items"
ITEM_ID_KEY = "item_id"
ITEM_KEY = "item"
ITEM_METADATA_SCHEMA_KEY = "item_metadata_schema"
JOB_ID_KEY = "job_id"
KEEP_HISTORY_KEY = "keep_history"
JOB_STATUS_KEY = "job_status"
JOB_LAST_KNOWN_STATUS_KEY = "job_last_known_status"
JOB_TYPE_KEY = "job_type"
JOB_CREATION_TIME_KEY = "job_creation_time"
LABEL_KEY = "label"
MASK_URL_KEY = "mask_url"
MESSAGE_KEY = "message"
METADATA_KEY = "metadata"
MODEL_ID_KEY = "model_id"
MODEL_RUN_ID_KEY = "model_run_id"
NAME_KEY = "name"
NEW_ITEMS = "new_items"
NUCLEUS_ENDPOINT = "https://api.scale.com/v1/nucleus"
ORIGINAL_IMAGE_URL_KEY = "original_image_url"
POSITION_KEY = "position"
PREDICTIONS_IGNORED_KEY = "predictions_ignored"
PREDICTIONS_PROCESSED_KEY = "predictions_processed"
REFERENCE_IDS_KEY = "reference_ids"
REFERENCE_ID_KEY = "reference_id"
REQUEST_ID_KEY = "requestId"
SEGMENTATIONS_KEY = "segmentations"
SLICE_ID_KEY = "slice_id"
STATUS_CODE_KEY = "status_code"
STATUS_KEY = "status"
SUCCESS_STATUS_CODES = [200, 201, 202]
TYPE_KEY = "type"
UPDATED_ITEMS = "updated_items"
UPDATE_KEY = "update"
VERTICES_KEY = "vertices"
WIDTH_KEY = "width"
YAW_KEY = "yaw"
X_KEY = "x"
Y_KEY = "y"
Z_KEY = "z"
